<?php

/**
* Parses the Twitter search feed eg. http://search.twitter.com/search.atom?q=world cup
* and maps it the fields of the feed_item_twitter node type.
*/
class FeedsTwitterParser extends FeedsParser {

  /**
  * Parses a raw string and populates FeedsImportBatch object from it.
  */
  public function parse(FeedsImportBatch $batch, FeedsSource $source) {
    // Get the file's content.
    $string = $batch->getRaw();

    // Parse it...
    // The parsed result should be an array of arrays of field name => value.
    $xml = simplexml_load_string($string);
    
    foreach($xml->entry as $id => $obj_entry){
    	
    	$tmp_link[0] = (array)$obj_entry->link[0]['href'];
    	$tmp_link[1] = (array)$obj_entry->link[1]['href'];
    	
    	$items[] = array(
    		'guid' 		=> $obj_entry->id,
    		'published' 	=> strtotime($obj_entry->published),
    		'tweet_link' 	=> $tmp_link[0],
    		'author_pic' 	=> $tmp_link[1],
    		'tweet_text' 	=> $obj_entry->title,
    		'tweet_html'	=> $obj_entry->content,
    		'updated'	=> strtotime($obj_entry->updated),
    		'author_name'	=> $obj_entry->author->name,
    		'author_uri'	=> $obj_entry->author->uri
    	);
    	
    	//print_r($items); 
    	//exit;
    	unset($tmp_link);
    }

    // Populate the FeedsImportBatch object with the parsed results.
    $batch->setTitle($obj_entry->title);
    $batch->setItems($items);
  }

  public function getMappingSources() {
    return array(
      'guid' => array(
        'name' => t('GUID'),
        'description' => t('Unique ID.'),
      ),
      'published' => array(
        'name' => t('Date published'),
        'description' => t('Date when the tweet was published.'),
      ),
      'tweet_link' => array(
        'name' => t('Tweet link'),
        'description' => t('Link to the original tweet.'),
      ),
      'author_pic' => array(
        'name' => t('Author\'s pic'),
        'description' => t('Tweet author\'s pic.'),
      ),
      'tweet_text' => array(
        'name' => t('Tweet (txt)'),
        'description' => t('Text version of the tweet.'),
      ),
      'tweet_html' => array(
        'name' => t('Tweet (html)'),
        'description' => t('HTML version of the tweet.'),
      ),
      'updated' => array(
        'name' => t('Date updated'),
        'description' => t('Date when the tweet was updated.'),
      ), 
      'author_name' => array(
        'name' => t('Author\'s Name'),
        'description' => t('Tweet\'s author\'s name.'),
      ),
      'author_uri' => array(
        'name' => t('Authors\' URL'),
        'description' => t('Tweet\'s author\'s URL.'),
      ),                                         
    );
  }

} 